@@ -184,7 +184,7 @@ from musamusa_etr.etr_line import ETRLINE_INTTYPE__PARSINGTOOLSDEFINITION
 from musamusa_etr.etr_line import ETRLINE_INTTYPE__VARIABLE, ETRLINE_INTTYPE__TAG
 from musamusa_etr.etr_line import ETRLINE_INTTYPE__NONE
 
-# PARSINGTOOLS is the default value of ETR.parsingtools
+# DEFAULT_PARSINGTOOLS is the default value of ETR.parsingtools
 #
 # (pimydoc)ETR.parsingtools
 # ⋅ETR.parsingtools is an attribute (NOT a class attribute).
@@ -215,19 +215,19 @@ from musamusa_etr.etr_line import ETRLINE_INTTYPE__NONE
 # ⋅
 # ⋅If a key contains the "(json)" suffix, its value is a Python object
 # ⋅that can be read from a string through json.loads()
-PARSINGTOOLS = {
-        "comment_lineprefix": "#",
-        "tobecontinued_char": "⬂",
-        "allow_leftspaces_syntax(json)": True,
-        "filetobeincluded_lineprefix": "+++",
-        "tag_kv(regex)": re.compile(r"^\:(?P<name>[^:]+)\:\s*"
-                                    r"(?P<key>[^\s]*)\s*"
-                                    r"(\:\s*(?P<value>[^\s]*))?\s*$"),
-        "authorised tags(json)": ("abbreviation", "flag"),
-        "variable(regex)": re.compile(r"^\/(?P<name>[^\s]+)\/\s*"
-                                      r"(?P<value>.*)\s*$"),
-        "parsingtools_definition(regex)": re.compile(r"%%(?P<name>[^:]+)%%(?P<value>.+)\s*$"),
-        }
+DEFAULT_PARSINGTOOLS = {
+    "comment_lineprefix": "#",
+    "tobecontinued_char": "⬂",
+    "allow_leftspaces_syntax(json)": True,
+    "filetobeincluded_lineprefix": "+++",
+    "tag_kv(regex)": re.compile(r"^\:(?P<name>[^:]+)\:\s*"
+                                r"(?P<key>[^\s]*)\s*"
+                                r"(\:\s*(?P<value>[^\s]*))?\s*$"),
+    "authorised tags(json)": ("abbreviation", "flag"),
+    "variable(regex)": re.compile(r"^\/(?P<name>[^\s]+)\/\s*"
+                                  r"(?P<value>.*)\s*$"),
+    "parsingtools_definition(regex)": re.compile(r"%%(?P<name>[^:]+)%%(?P<value>.+)\s*$"),
+}
 
 
 # (pimydoc)ETR.options
@@ -370,8 +370,11 @@ class ETR:
             o (None/dict)parsingtools, a dict of regexes and list of
               chars allowing to detect markers in the source string.
 
-              Default parsingtools are defined in the PARSINGTOOLS variable.
-              See PARSINGTOOLS initialization to understant <parsingtools>
+              parsingtools is an update of DEFAULT_PARSINGTOOLS, i.e. <parsingtools>
+              may contain only one value which will modify the copy of DEFAULT_PARSINGTOOLS.
+
+              Default parsingtools are defined in the DEFAULT_PARSINGTOOLS variable.
+              See DEFAULT_PARSINGTOOLS initialization to understant <parsingtools>
               format.
 
               About the <parsingtools> argument:
@@ -380,6 +383,9 @@ class ETR:
                   setting <parsingtools> to a dict {...}.
 
             o options :
+                options is an update of DEFAULT_OPTIONS, i.e. <options> may contain only one
+                value which will modify the copy of DEFAULT_OPTIONS.
+
                 (pimydoc)ETR.options
                 ⋅ETR.options is a dict(str:None|bool|func) describing what to when reading/writing.
                 ⋅
@@ -448,11 +454,9 @@ class ETR:
         # ⋅
         # ⋅If a key contains the "(json)" suffix, its value is a Python object
         # ⋅that can be read from a string through json.loads()
+        self.initialize_parsingtools_with_reasonable_values()
         if parsingtools:
-            self.parsingtools = parsingtools
-        else:
-            self.parsingtools = {}
-            self.initialize_parsingtools_with_reasonable_values()
+            self.parsingtools.update(parsingtools)
 
         # (pimydoc)ETR.options
         # ⋅ETR.options is a dict(str:None|bool|func) describing what to when reading/writing.
@@ -489,10 +493,9 @@ class ETR:
         # ⋅
         # ⋅Please not that there is no "read line:None:yield" entry since
         # ⋅None is always yielded in this case.
+        self.options = copy.deepcopy(DEFAULT_OPTIONS)
         if options:
-            self.options = options
-        else:
-            self.options = copy.deepcopy(DEFAULT_OPTIONS)
+            self.options.update(options)
 
         # (pimydoc)ETR.read_tags
         # ⋅Definition of all tags read in the read file(s).
@@ -584,7 +587,7 @@ class ETR:
             # ⋅... raises an error since "XYZx" isn't a key of .parsingtools .
             error = MusTextFileError()
             error.msgid = "ETR-ERRORID006"
-            error.msg = f"({error.msgid}) Ill-formed file : " \
+            error.msg = "Ill-formed file : " \
                 f"Illegal name ('{ptooldef.group('name')}') for a " \
                 "'parsingtools_definition(regex)'. " \
                 f"Authorized names are {tuple(self.parsingtools.keys())}."
@@ -642,7 +645,7 @@ class ETR:
                     # ⋅    ^\:?P<name>[^:]+)\...
                     error = MusTextFileError()
                     error.msgid = "ETR-ERRORID007"
-                    error.msg = f"({error.msgid}) Ill-formed file : " \
+                    error.msg = "Ill-formed file : " \
                         f"can't interpret new parsingtools_definition. " \
                         f"Can't compile regex {ptooldef.group('value')} " \
                         f"Python error is '{err}' ."
@@ -666,7 +669,7 @@ class ETR:
                     # ⋅  %%authorised tags(json)%%("abbreviation", "tag")
                     error = MusTextFileError()
                     error.msgid = "ETR-ERRORID008"
-                    error.msg = f"({error.msgid}) Ill-formed file : " \
+                    error.msg = "Ill-formed file : " \
                         "can't interpret json string " \
                         f"'{ptooldef.group('value')}'. " \
                         f"Python error is '{err}' ."
@@ -708,7 +711,7 @@ class ETR:
                "value" not in regex.groupindex:
                 error = MusTextFileError()
                 error.msgid = "ETR-ERRORID011"
-                error.msg = f"({error.msgid}) Ill-formed file : " \
+                error.msg = "Ill-formed file : " \
                     "Regex defined for 'parsingtools_definition(regex)' tag" \
                     "must have a 'name' and a 'value' group names." \
                     f"Read regex is '{regex.pattern}'; regex.groupindex is {regex.groupindex} ."
@@ -731,7 +734,7 @@ class ETR:
                "value" not in regex.groupindex:
                 error = MusTextFileError()
                 error.msgid = "ETR-ERRORID012"
-                error.msg = f"({error.msgid}) Ill-formed file : " \
+                error.msg = "Ill-formed file : " \
                     "Regex defined for 'tag_kv(regex)' tag" \
                     "must have a 'name', a 'value' and a 'key' group names." \
                     f"Read regex is '{regex.pattern}'; regex.groupindex is {regex.groupindex} ."
@@ -821,7 +824,7 @@ class ETR:
                     # ⋅... raises an error since "ᵛⁱ" is defined twice as an abbreviation.
                     error = MusTextFileError()
                     error.msgid = "ETR-ERRORID004"
-                    error.msg = f"({error.msgid}) Ill-formed file : " \
+                    error.msg = "Ill-formed file : " \
                         f"Duplicate tag key '{tag.group('key')}'"
                     error.fals = fals
                     self.errors.append(error)
@@ -839,8 +842,7 @@ class ETR:
                         # ⋅... will raise an error since abbreviation "V" has no value.
                         error = MusTextFileWarning()
                         error.msgid = "ETR-ERRORID009"
-                        error.msg = f"({error.msgid}) " \
-                                    f"Can't read abbreviation '{tag.group('key')}' : empty content."
+                        error.msg = f"Can't read abbreviation '{tag.group('key')}' : empty content."
                         error.fals = fals
                         self.errors.append(error)
 
@@ -854,8 +856,7 @@ class ETR:
                         # ⋅... will raise an error since flag "ł" has no value.
                         error = MusTextFileWarning()
                         error.msgid = "ETR-ERRORID010"
-                        error.msg = f"({error.msgid}) " \
-                                    f"Can't read flag '{tag.group('key')}' : empty content."
+                        error.msg = f"Can't read flag '{tag.group('key')}' : empty content."
                         error.fals = fals
                         self.errors.append(error)
 
@@ -873,7 +874,7 @@ class ETR:
                 # ⋅.parsingtools["authorised tags(json)"].
                 error = MusTextFileError()
                 error.msgid = "ETR-ERRORID005"
-                error.msg = f"({error.msgid}) Ill-formed file : " \
+                error.msg = "Ill-formed file : " \
                     f"Unknown tag name '{tag.group('name')}'; " \
                     "Authorized tag names are: " \
                     f"{self.parsingtools['authorised tags(json)']}."
@@ -923,8 +924,7 @@ class ETR:
                 # ⋅... since the value read for 'variable_name' is an empty string.
                 error = MusTextFileError()
                 error.msgid = "ETR-ERRORID013"
-                error.msg = f"({error.msgid}) " \
-                    "A variable value can't be an empty string. " \
+                error.msg = "A variable value can't be an empty string. " \
                     f"Variable read was '{variable.group('name')}'."
                 error.fals = fals
                 self.errors.append(error)
@@ -975,8 +975,7 @@ class ETR:
         if source_filename in self._nested_files:
             error = MusTextFileError()
             error.msgid = "ETR-ERRORID002"
-            error.msg = f"({error.msgid}) " \
-                f"Cyclic import in '{source_filename}' ." \
+            error.msg = "Cyclic import in '{source_filename}' ." \
                 f"Parent files already read are f{self._nested_files}"
             self.errors.append(error)
             yield from self._read_action(TLFF(line_inttype=ETRLINE_INTTYPE__NONE))
@@ -989,8 +988,7 @@ class ETR:
         if not os.path.exists(source_filename):
             error = MusTextFileError()
             error.msgid = "ETR-ERRORID000"
-            error.msg = f"({error.msgid}) " \
-                f"Missing ETR MusaMusa text file '{source_filename}' ."
+            error.msg = "Missing ETR MusaMusa text file '{source_filename}' ."
             self.errors.append(error)
             yield from self._read_action(TLFF(line_inttype=ETRLINE_INTTYPE__NONE))
             return
@@ -1006,7 +1004,7 @@ class ETR:
             # ⋅reading loop.
             error = MusTextFileError()
             error.msgid = "ETR-ERRORID003"
-            error.msg = f"({error.msgid}) Can't read '{source_filename}'. " \
+            error.msg = f"Can't read '{source_filename}'. " \
                 f"Python error is (KeyError)'{traceback.format_exc()}'."
             self.errors.append(error)
 
@@ -1059,7 +1057,7 @@ class ETR:
                    not _line.strip().endswith(self.parsingtools["tobecontinued_char"]):
                     error = MusTextFileWarning()
                     error.msgid = "ETR-WARNINGID000"
-                    error.msg = f"({error.msgid}) Maybe a problem in a file : " \
+                    error.msg = "Maybe a problem in a file : " \
                         f"tobecontinued_char '{self.parsingtools['tobecontinued_char']}' " \
                         "found elsewhere than at the end of the line where it should have been."
                     error.fals = (FileAndLine(filename=source_filename,
@@ -1150,7 +1148,7 @@ class ETR:
                     if next_line is None:
                         error = MusTextFileError()
                         error.msgid = "ETR-ERRORID001"
-                        error.msg = f"({error.msgid}) Ill-formed file : " \
+                        error.msg = "Ill-formed file : " \
                             "first line can't be added to a precedent line " \
                             "since the first character(s) of the first " \
                             "line are spaces " \
@@ -1269,10 +1267,7 @@ class ETR:
         """
         if tlff.line_inttype == ETRLINE_INTTYPE__NORMAL:
             if self.options["read line:normal:event"]:
-                self.options["read line:normal:event"](tlff.fals,
-                                                       tlff.flags,
-                                                       tlff.line,
-                                                       tlff.line_inttype,
+                self.options["read line:normal:event"](tlff,
                                                        details)
 
             if self.options["read line:normal:yield"]:
@@ -1284,10 +1279,7 @@ class ETR:
 
         elif tlff.line_inttype == ETRLINE_INTTYPE__COMMENTEMPTY:
             if self.options["read line:empty line/comment:event"]:
-                self.options["read line:empty line/comment:event"](tlff.fals,
-                                                                   tlff.flags,
-                                                                   tlff.line,
-                                                                   tlff.line_inttype,
+                self.options["read line:empty line/comment:event"](tlff,
                                                                    details)
 
             if self.options["read line:empty line/comment:yield"]:
@@ -1339,10 +1331,7 @@ class ETR:
         """
         if tlff.line_inttype == ETRLINE_INTTYPE__PARSINGTOOLSDEFINITION:
             if self.options["read line:parsingtools_definition:event"]:
-                self.options["read line:parsingtools_definition:event"](tlff.fals,
-                                                                        tlff.flags,
-                                                                        tlff.line,
-                                                                        tlff.line_inttype,
+                self.options["read line:parsingtools_definition:event"](tlff,
                                                                         details)
 
             if self.options["read line:parsingtools_definition:yield"]:
@@ -1354,10 +1343,7 @@ class ETR:
 
         elif tlff.line_inttype == ETRLINE_INTTYPE__VARIABLE:
             if self.options["read line:variable:event"]:
-                self.options["read line:variable:event"](tlff.fals,
-                                                         tlff.flags,
-                                                         tlff.line,
-                                                         tlff.line_inttype,
+                self.options["read line:variable:event"](tlff,
                                                          details)
 
             if self.options["read line:variable:yield"]:
@@ -1369,10 +1355,7 @@ class ETR:
 
         elif tlff.line_inttype == ETRLINE_INTTYPE__TAG:
             if self.options["read line:tag:event"]:
-                self.options["read line:tag:event"](tlff.fals,
-                                                    tlff.flags,
-                                                    tlff.line,
-                                                    tlff.line_inttype,
+                self.options["read line:tag:event"](tlff,
                                                     details)
 
             if self.options["read line:tag:yield"]:
@@ -1384,10 +1367,7 @@ class ETR:
 
         elif tlff.line_inttype is ETRLINE_INTTYPE__NONE:
             if self.options["read line:None:event"]:
-                self.options["read line:None:event"](tlff.fals,
-                                                     tlff.flags,
-                                                     tlff.line,
-                                                     tlff.line_inttype,
+                self.options["read line:None:event"](tlff,
                                                      details)
 
             # These lines are superfluous as the value None will be yielded
@@ -1403,7 +1383,7 @@ class ETR:
             by example for testing.
 
             Wrapper around:
-                self.parsingtools = copy.deepcopy(PARSINGTOOLS)
+                self.parsingtools = copy.deepcopy(DEFAULT_PARSINGTOOLS)
 
             (pimydoc)ETR.parsingtools
             ⋅ETR.parsingtools is an attribute (NOT a class attribute).
@@ -1439,7 +1419,7 @@ class ETR:
 
             no RETURNED VALUE
         """
-        self.parsingtools = copy.deepcopy(PARSINGTOOLS)
+        self.parsingtools = copy.deepcopy(DEFAULT_PARSINGTOOLS)
 
     def postread_checks(self):
         """
@@ -1457,7 +1437,7 @@ class ETR:
             if tag_name not in self.read_tags or not self.read_tags[tag_name]:
                 error = MusTextFileWarning()
                 error.msgid = "ETR-WARNINGID001"
-                error.msg = f"({error.msgid}) Maybe a problem in the read file(s) : " \
+                error.msg = "Maybe a problem in the read file(s) : " \
                     "authorised tags " \
                     f"are {self.parsingtools['authorised tags(json)']} " \
                     f"but the file(s) doesn't have any data for tag '{tag_name}' ."
